Install - 安装
==============

Use pip - 使用 pip
------------------

zhihu_oauth 支持 Python 2 和 Python 3，用对应版本的 pip 安装即可。

..  code-block:: bash

    pip install zhihu_oauth

..  note:: 提示

    请自行判断是否要加上 ``sudo`` 命令。

    请自行选择对应的 pip 版本（如 ``pip3``，``pip2.7``）替换上述命令中的 ``pip``。

如果不报错大概就是安装成功了。

Use git - 使用 git
------------------

..  warning:: 别！

    不推荐用这种方法安装！pip 还满足不了你么！？


..  code-block:: bash

    git clone https://github.com/7sDream/zhihu-oauth.git
    cd zhihu_oauth
    python setup.py install

..  note:: 提示

    请自行判断是否要加上 ``sudo`` 命令。

    请自行选择对应的 python 版本（如 ``python3``，``python2.7``）
    替换上述命令中的 ``python``。

如果不报错大概就是安装成功了。
